import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { highlightText } from '@s-ui/js/lib/string';
import AtomCheckbox from '@s-ui/react-atom-checkbox';
import handlersFactory from './handlersFactory';
var BASE_CLASS = 'sui-MoleculeDropdownOption';
var CLASS_CHECKBOX = BASE_CLASS + "-checkbox";
var MODIFIER_TWO_LINES = "twoLines";
var MODIFIER_ELLIPSIS = 'ellipsis';
var CLASS_TEXT = BASE_CLASS + "-text";
var CLASS_DISABLED = BASE_CLASS + "--disabled";
var CLASS_HIGHLIGHTED = "is-highlighted";
var CLASS_HIGHLIGHTED_MARK = BASE_CLASS + "-mark";

var MoleculeDropdownOption = function MoleculeDropdownOption(_ref) {
  var _cx;

  var children = _ref.children,
      selected = _ref.selected,
      checkbox = _ref.checkbox,
      disabled = _ref.disabled,
      highlightQuery = _ref.highlightQuery,
      onSelectKey = _ref.onSelectKey,
      onSelect = _ref.onSelect,
      innerRef = _ref.innerRef,
      value = _ref.value,
      withTwoLinesText = _ref.withTwoLinesText;
  var className = cx(BASE_CLASS, (_cx = {}, _cx[CLASS_CHECKBOX] = checkbox, _cx[CLASS_DISABLED] = disabled, _cx['is-selected'] = selected, _cx));
  var innerClassName = cx([CLASS_TEXT, withTwoLinesText ? CLASS_TEXT + "--" + MODIFIER_TWO_LINES : CLASS_TEXT + "--" + MODIFIER_ELLIPSIS]);

  var _handlersFactory = handlersFactory({
    disabled: disabled,
    value: value,
    onSelectKey: onSelectKey,
    onSelect: onSelect
  }),
      handleClick = _handlersFactory.handleClick,
      handleKeyDown = _handlersFactory.handleKeyDown,
      handleFocus = _handlersFactory.handleFocus;

  var renderHighlightOption = function renderHighlightOption(option) {
    if (typeof option !== 'string') {
      return /*#__PURE__*/React.createElement("span", {
        onFocus: handleInnerFocus,
        className: innerClassName
      }, option);
    }

    var mark = highlightText({
      value: option,
      query: highlightQuery,
      startTag: "<mark class=\"" + cx(CLASS_HIGHLIGHTED_MARK, CLASS_HIGHLIGHTED) + "\">",
      endTag: '</mark>'
    });
    return /*#__PURE__*/React.createElement("span", {
      onFocus: handleInnerFocus,
      dangerouslySetInnerHTML: {
        __html: mark
      },
      className: innerClassName
    });
  };

  var handleInnerFocus = function handleInnerFocus(ev) {
    ev.preventDefault();
    innerRef.current.focus();
  };

  return /*#__PURE__*/React.createElement("li", {
    ref: innerRef,
    tabIndex: "0",
    className: className,
    onClick: handleClick,
    onKeyDown: handleKeyDown,
    onFocus: handleFocus
  }, checkbox && /*#__PURE__*/React.createElement(AtomCheckbox, {
    checked: selected,
    disabled: disabled,
    onFocus: handleInnerFocus
  }), highlightQuery ? renderHighlightOption(children) : /*#__PURE__*/React.createElement("span", {
    onFocus: handleInnerFocus,
    className: innerClassName
  }, children));
};

MoleculeDropdownOption.displayName = 'MoleculeDropdownOption';
MoleculeDropdownOption.defaultProps = {
  checkbox: false,
  disabled: false,
  onSelect: function onSelect() {},
  selected: false,
  onSelectKey: 'Enter',
  innerRef: React.createRef()
};
export default MoleculeDropdownOption;
export { handlersFactory };